==> deepin-home_1.0.3.orig.tar.xz: deepin-home-1.0.3/translations/deepin-home/zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>敬請期待</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>互動交流</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>社區用戶交流分享</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Bug反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>日常使用問題反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>需求反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>對操作系統的好建議</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>社區相關</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>問卷調查</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>加入我們</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>內測交流</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>社區動態</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="278"/>
        <source>Network error, please try later</source>
        <translation>網絡錯誤，請稍後再試</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>系統消息</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>調查問卷</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>開機自啟</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Messages</source>
        <translation>深度消息</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>未登錄</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="118"/>
        <source>Sign in</source>
        <translation>登錄</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="130"/>
        <source>Sign out</source>
        <translation>登出</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>當前無通知訊息，感謝您的關注！</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>共%1條</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>一鍵已讀</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>查看更多</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>當前無問卷訊息，感謝您的關注！</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>有效期至：%1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>填寫</translation>
    </message>
</context>
</TS>

==> deepin-home_1.0.5.orig.tar.xz: deepin-home-1.0.5/translations/deepin-home/zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>敬請期待</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>互動交流</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>社區用戶交流分享</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Bug反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>日常使用問題反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>需求反饋</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>對操作系統的好建議</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>社區相關</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>問卷調查</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>加入我們</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>內測交流</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="164"/>
        <source>Community News</source>
        <translation>社區動態</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="281"/>
        <source>Network error, please try later</source>
        <translation>網絡錯誤，請稍後再試</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>系統消息</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>調查問卷</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>開機自啟</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Home</source>
        <translation>深度之家</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>未登錄</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="119"/>
        <source>Sign in</source>
        <translation>登錄</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="131"/>
        <source>Sign out</source>
        <translation>登出</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>當前無通知訊息，感謝您的關注！</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="149"/>
        <source>%1 messages</source>
        <translation>共%1條</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="153"/>
        <source>Mark all as read</source>
        <translation>一鍵已讀</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>查看更多</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>當前無問卷訊息，感謝您的關注！</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="89"/>
        <source>Expired on: %1</source>
        <translation>有效期至：%1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="117"/>
        <source>Fill In</source>
        <translation>填寫</translation>
    </message>
</context>
</TS>
